==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/mail/inc/function.folder.php <==
<?
//18.12.2005
function parsepath($dir){
  global $id,$otherconfig;
  if (!$dir || !$id || !is_array($otherconfig)) die('parsepath() - invalid input variables');
  if (!ereg("/$",$dir)) $dir.='/';

  getusersession($id, $user, $config);

  $path = str_replace("\\","/",usersdir . $user . "/");

  if (directmerak && $otherconfig["FULLMERAK"])
     $xpath = str_replace("\\","/",getmailboxpath($user, $imap, false));

  if ($xpath && strpos($dir,$xpath)===0){
     if(strpos($path,$xpath)===0 && strpos($dir,$path)===0) $xpath = $path;
     if($dir==$xpath) return inboxfolder;
     return substr($dir,strlen($xpath),-1);
  }

  if ($path && strpos($dir,$path)===0) {
     if($dir==$path) return inboxfolder;
     return substr($dir,strlen($path),-1);
  }

  die('parsepath() - invalid folder');
}

//02.12.2005
function parseindex($path,&$messages,&$unread,&$size,&$subdirs){

   $messages = $unread = $size = 0;
   $subdirs   = array();
   if (!ereg("/$",$path)) $path.='/';

   if (@file_exists($path.'index.dat') && $file = file($path.'index.dat')) {

      $data = explode(',',$file[0]);
      $messages = (int)$data[0];
      $unread   = (int)$data[1];
      $size     = (int)$data[2];

      //index.dat from old version
      if (($messages*1)>0 && !$size)
         indexfolder($path,$messages,$unread,$size,$subdirs);
      else {
         if (trim($file[1])){
            if (count($file)>2){
               unset($file[0]);
               $filesrl = implode("\r\n",$file);
            }
            else
               $filesrl = $file[1];

            $subdirs = unserialize(trim($filesrl));
         }
      }
      return true;
   }
   return false;
}

//02.12.2005
function saveindex($path,$cf,$cuf,$size,$subdir="")
{
  if(is_dir($path))
  {
    if (@$fp=fopen($path."/index.dat","wb")){
       $cuf = $cf<$cuf?$cf:$cuf;
       fputs($fp,($cf<0?0:$cf).','.($cuf<0?0:$cuf).','.($size<0?0:$size),1000);
       if (is_array($subdir) && count($subdir)) fputs($fp,"\r\n".serialize($subdir));
       @fclose($fp);
    }
  }
}

//28.11.2005
function changeindex($path,$messages,$unread,$size=0,$addir='',$subdir='')
{
   if(!is_dir($path)) return;
   $subdirs = array();
   $path = (strrpos($path,"/")+1)===strlen($path)?$path:"$path/";

   if(parseindex($path,$messages0,$unread0,$size0,$subdirs)){
      $messages += $messages0;
      $unread   += $unread0;
      $size     += $size0;
   }

   if ($addir && !in_array($addir,$subdirs)) $subdirs[] = $addir;

   if ($subdir){
      $key = array_search($subdir,$subdirs);
      if($key!==null) unset($subdirs[$key]);
      sort($subdirs);
   }

   if ($messages>0 || count($subdirs)>0)
      saveindex($path,$messages,$unread,$size,$subdirs);
   else
      @unlink($path.'index.dat');

   return true;
}


  function indexfolder($path,&$messages,&$unread,&$size,&$folders)
  {
    global $id,$user;

    $folders = array();
    $messages = $unread = $size = 0;

    if (!(@$dp = opendir($path))) return false;

    // get $folder var
    $folder = parsepath($path);

    while (@$dir = readdir($dp))
    {
      if ($dir == '.' || $dir == '..') continue;

      // index folders
      if (is_dir($path.$dir))
         $folders[] = $dir;
      // index files
      elseif(($pos = strrpos($dir,'.'))){

         $ext = strtolower(substr($dir,$pos));
         if ($ext !== messageext && $ext !== imapmessageext) continue;
         if(!($fsize = @filesize($path.$dir))) continue;
         $size += $fsize;
         $messages++;
         if (getmessageflag($id, $folder, $dir) == unreadflag) $unread++;
      }
    }

    if ($messages>0 || count($folders)>0)
       saveindex($path,$messages,$unread,$size,$folders);
    elseif(file_exists($path."index.dat"))
       @unlink($path."index.dat");

    return true;
  }


  //03.12.2005
  function showfolderinfo($folder,$switch=1)
  {
    global $messagestext, $unreadtext;

    switch($switch){
       case 1:
              return "(" . $folder['messages'] . " " . $messagestext . ", " . $folder['unread'] . " " . $unreadtext . ")";
       case 2:
              return "(" . $folder['messages'] . ($folder['unread']?", <b>".$folder['unread']."</b>":''). ")";
       default:
              return "(" . $folder['messages'] . ($folder['unread']?", ".$folder['unread']:''). ")";
    }
  }

  function validatefolder($folder,$encode="0")
  {
    $folder = str_replace("\\","/",trim($folder));

    //shared folder fix [balanced install]
    if (strpos($folder,"//")===0){
       $addslash="//";
       $folder = substr($folder,2);
    }

    while(ereg("(\.\.)|(//)",$folder)) $folder = ereg_replace("(\.){2,}|(/){2,}|(\|)*","",$folder);

    $folder = $addslash.$folder;

    if($encode) {
      if(strcasecmp(mycharset,"us-ascii")) $folder = charsetconvert($folder,mycharset,"UTF7-IMAP");
      return str_replace("?","_",$folder);
    }
    else
      return $folder;
  }

  function convert_imaputf2charset($item,$charset=mycharset)
  {
    if(ereg("\&([a-zA-Z0-9\,\+])+\-",$item) && strcasecmp($charset,"us-ascii"))
    {
      $item = charsetconvert($item,"UTF7-IMAP",$charset);
      $item = str_replace("\x00","",$item);
      $item = str_replace("?","_",$item);
    }
    return $item;
  }


function getoptionfolder($id,$folders="",$folder="",$switch="",&$folderlist)
{
  if(!is_array($folders)) $folders = getfolders($id);

  for ($i = 0; $i < count($folders); $i++)
  {
          $folderlistitem = '<option value="'. $folders[$i][0].'"';

          if ($cpos = strpos($folders[$i][0],"^"))
             $compare = substr($folders[$i][0],0,$cpos);
          else
             $compare = $folders[$i][0];

          if ($folder && !(strcasecmp($folder,$compare)))
          {
                  $actualfolder_name = $folders[$i][1];
                  $folderlistitem .= ' selected';
          }

          $rslash = strrpos($folders[$i][1],"/");
          if($rslash>0)
          {
            $count=substr_count($folders[$i][1],"/");
            $nbsp="";
            for($ii=0;$ii<$count;$ii++) $nbsp.="-&nbsp;";
            $fname = substr($folders[$i][1],$rslash+1);
            if (strlen($fname)>21)
               $fname = substr($fname,0,18)."...";

            $folders[$i][1]= $nbsp.htmlspecialchars($fname);
          }
          elseif(strlen($folders[$i][1])>21)
            $folders[$i][1] = htmlspecialchars(substr($folders[$i][1],0,18))."...";

          $folderlistitem .= '>'. $folders[$i][1];
          if($switch) $folderlistitem .=' ' . showfolderinfo($folders[$i],$switch)."</option>\r\n"; else $folderlistitem .="</option>\r\n";

          $folderlists[] = $folderlistitem;
  }
  $folderlist = implode("", $folderlists);
  return $actualfolder_name;
}

////////////////////////////////////////////////////////////////////////////
//                              F O L D E R S                             //
////////////////////////////////////////////////////////////////////////////

  //03.12.2005
  function getfolderlist($path, &$folders, $dirlen="",$subdir=false)
  {
       global $otherconfig;

       if ($subdir){
          $fkey = count($folders)-1;
          if (!@file_exists($path.'index.dat'))
             indexfolder($path,$folders[$fkey]['messages'],$folders[$fkey]['unread'],$folders[$fkey]['size'],$xfolders);
          else
             parseindex($path,$folders[$fkey]['messages'],$folders[$fkey]['unread'],$folders[$fkey]['size'],$xfolders);
       }
       else {
          if(!$xfolders = glob("$path*",GLOB_ONLYDIR)) return false;
          $dirlen = strlen($path);
       }

       foreach ($xfolders as $dir) {
          if($subdir) $dir = $path.$dir;
          $folder = substr($dir,$dirlen);

          if ($subdir && !is_dir($dir)){
             changeindex($path,0,0,0,'',basename($dir));
             continue;
          }

          if ($folder[0]=='~') {
             if (!strcasecmp("$folder/",spamfolder.'/'))
                $folder = spamfolder;
             else
               continue;
          }

          $folders[] = array($folder,convert_imaputf2charset($folder),'');
          
          getfolderlist("$dir/", $folders, $dirlen, 1);
       }
  }

  //Fodler sort function
  function sortka(&$a,&$b){return strnatcasecmp($a[0],$b[0]);}

  //3.12.2005
  function getfolders($id)
  {
    global $otherconfig, $mailboxspam;
    getusersession($id, $user, $config);

    $path = usersdir . $user . "/";

    if (directmerak && $otherconfig["FULLMERAK"]) {
       $xpath = getmailboxpath($user, $imap, false);
       if ($imap || $otherconfig["MERAKMAILFOLDER"]) $path = $xpath;
    }
    $path = str_replace("\\","/",$path);

    getfolderlist($path, $folders2);

    if (is_array($folders2)) {
       usort($folders2,"sortka");

       foreach($folders2 as $key => $value) {
         if(strpos($value[0].'/',inboxfolder.'/')===0) {
           $finbox[]=$value;
           unset($folders2[$key]);
         }
         if(strpos($value[0].'/',draftsfolder.'/')===0) {
           $fdraft[]=$value;
           unset($folders2[$key]);
         }
         if(strpos($value[0].'/',sentfolder.'/')===0) {
           $fsent[]=$value;
           unset($folders2[$key]);
         }

         if(strpos($value[0].'/',trashfolder.'/')===0) {

           // trashfolder clean up
           if ($value[0]==trashfolder && $otherconfig["DELETETRASH"]) {
              if (($trfiles = glob($path.trashfolder."/*.{tmp,imap}",GLOB_BRACE))){
                 $ctime = time()-($otherconfig["DELETETRASH"] * 86400);
                 $trmssg  = $trumssg = $trsize = 0;
                 foreach ($trfiles as $trdir) {
                    if (filectime($trdir)<$ctime){
                       $trmssg--;
                       $trsize-=filesize($trdir);
                       $myflag = basename($trdir);
                       if (getmessageflag($id, trashfolder, $myflag) == unreadflag) $trumssg--;
                       @unlink($trdir);
                    }
                 }
                 if ($trmssg<0){
                    changeindex($path.trashfolder,$trmssg,$trumssg,$trsize);
                    $value['messages'] += $trmssg;
                    $value['unread'] += $trumssg;
                    $value['size'] += $trsize;
                 }
              }
           }

           $frash[]=$value;
           unset($folders2[$key]);
         }

         if(strpos($value[0].'/',spamfolder.'/')===0) {
           $fspam[]=$value;
           unset($folders2[$key]);
         }
       }
    }

    $finbox[0][0] = inboxfolder;
    $finbox[0][1] = uinboxfolder;
    $finbox[0][2] = " disabled";
    if (directmerak && $otherconfig["FULLMERAK"] && !$imap) {
          $popath = getfolderpath($user,inboxfolder);
          if (file_exists($popath.'index.dat'))
             parseindex($popath,$finbox[0]['messages'],$finbox[0]['unread'],$finbox[0]['size'],$x);
          else
             indexfolder($popath,$finbox[0]['messages'],$finbox[0]['unread'],$finbox[0]['size'],$x);
    }




    $fdraft[0][0] = draftsfolder;
    $fdraft[0][1] = udraftsfolder;
    $fdraft[0][2] = " disabled";

    $fsent[0][0] = sentfolder;
    $fsent[0][1] = usentfolder;
    $fsent[0][2] = " disabled";

    $frash[0][0] = trashfolder;
    $frash[0][1] = utrashfolder;
    $frash[0][2] = " disabled";

    $folders = array_merge($finbox,$fdraft,$fsent,$frash);

    if ($mailboxspam) {
       $fspam[0][0] = spamfolder;
       $fspam[0][1] = uspamfolder;
       $fspam[0][2] = " disabled";
       if (directmerak && $otherconfig["FULLMERAK"] && !$imap && !$otherconfig["MERAKMAILFOLDER"]) {
             $popath = getfolderpath($user,spamfolder);
             if (file_exists($popath.'index.dat'))
                parseindex($popath,$fspam[0]['messages'],$fspam[0]['unread'],$fspam[0]['size'],$x);
             else
                indexfolder($popath,$fspam[0]['messages'],$fspam[0]['unread'],$fspam[0]['size'],$x);
       }
       $folders = array_merge($folders,$fspam);
    }

    if(is_array($folders2)) $folders=array_merge($folders,$folders2);

    return $folders;
  }
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/mail/inc/function.folder.php <==
<?
//18.12.2005
function parsepath($dir){
  global $id,$otherconfig;
  if (!$dir || !$id || !is_array($otherconfig)) die('parsepath() - invalid input variables');
  if (!ereg("/$",$dir)) $dir.='/';

  getusersession($id, $user, $config);

  $path = str_replace("\\","/",usersdir . $user . "/");

  if (directmerak && $otherconfig["FULLMERAK"])
     $xpath = str_replace("\\","/",getmailboxpath($user, $imap, false));

  if ($xpath && strpos($dir,$xpath)===0){
     if(strpos($path,$xpath)===0 && strpos($dir,$path)===0) $xpath = $path;
     if($dir==$xpath) return inboxfolder;
     return substr($dir,strlen($xpath),-1);
  }

  if ($path && strpos($dir,$path)===0) {
     if($dir==$path) return inboxfolder;
     return substr($dir,strlen($path),-1);
  }

  die('parsepath() - invalid folder');
}

//02.12.2005
function parseindex($path,&$messages,&$unread,&$size,&$subdirs){

   $messages = $unread = $size = 0;
   $subdirs   = array();
   if (!ereg("/$",$path)) $path.='/';

   if (@file_exists($path.'index.dat') && $file = file($path.'index.dat')) {

      $data = explode(',',$file[0]);
      $messages = (int)$data[0];
      $unread   = (int)$data[1];
      $size     = (int)$data[2];

      //index.dat from old version
      if (($messages*1)>0 && !$size)
         indexfolder($path,$messages,$unread,$size,$subdirs);
      else {
         if (trim($file[1])){
            if (count($file)>2){
               unset($file[0]);
               $filesrl = implode("\r\n",$file);
            }
            else
               $filesrl = $file[1];

            $subdirs = unserialize(trim($filesrl));
         }
      }
      return true;
   }
   return false;
}

//02.12.2005
function saveindex($path,$cf,$cuf,$size,$subdir="")
{
  if(is_dir($path))
  {
    if (@$fp=fopen($path."/index.dat","wb")){
       $cuf = $cf<$cuf?$cf:$cuf;
       fputs($fp,($cf<0?0:$cf).','.($cuf<0?0:$cuf).','.($size<0?0:$size),1000);
       if (is_array($subdir) && count($subdir)) fputs($fp,"\r\n".serialize($subdir));
       @fclose($fp);
    }
  }
}

//28.11.2005
function changeindex($path,$messages,$unread,$size=0,$addir='',$subdir='')
{
   if(!is_dir($path)) return;
   $subdirs = array();
   $path = (strrpos($path,"/")+1)===strlen($path)?$path:"$path/";

   if(parseindex($path,$messages0,$unread0,$size0,$subdirs)){
      $messages += $messages0;
      $unread   += $unread0;
      $size     += $size0;
   }

   if ($addir && !in_array($addir,$subdirs)) $subdirs[] = $addir;

   if ($subdir){
      $key = array_search($subdir,$subdirs);
      if($key!==null) unset($subdirs[$key]);
      sort($subdirs);
   }

   if ($messages>0 || count($subdirs)>0)
      saveindex($path,$messages,$unread,$size,$subdirs);
   else
      @unlink($path.'index.dat');

   return true;
}


  function indexfolder($path,&$messages,&$unread,&$size,&$folders)
  {
    global $id,$user;

    $folders = array();
    $messages = $unread = $size = 0;

    if (!(@$dp = opendir($path))) return false;

    // get $folder var
    $folder = parsepath($path);

    while (@$dir = readdir($dp))
    {
      if ($dir == '.' || $dir == '..') continue;

      // index folders
      if (is_dir($path.$dir))
         $folders[] = $dir;
      // index files
      elseif(($pos = strrpos($dir,'.'))){

         $ext = strtolower(substr($dir,$pos));
         if ($ext !== messageext && $ext !== imapmessageext) continue;
         if(!($fsize = @filesize($path.$dir))) continue;
         $size += $fsize;
         $messages++;
         if (getmessageflag($id, $folder, $dir) == unreadflag) $unread++;
      }
    }

    if ($messages>0 || count($folders)>0)
       saveindex($path,$messages,$unread,$size,$folders);
    elseif(file_exists($path."index.dat"))
       @unlink($path."index.dat");

    return true;
  }


  //03.12.2005
  function showfolderinfo($folder,$switch=1)
  {
    global $messagestext, $unreadtext;

    switch($switch){
       case 1:
              return "(" . $folder['messages'] . " " . $messagestext . ", " . $folder['unread'] . " " . $unreadtext . ")";
       case 2:
              return "(" . $folder['messages'] . ($folder['unread']?", <b>".$folder['unread']."</b>":''). ")";
       default:
              return "(" . $folder['messages'] . ($folder['unread']?", ".$folder['unread']:''). ")";
    }
  }

  function validatefolder($folder,$encode="0")
  {
    $folder = str_replace("\\","/",trim($folder));

    //shared folder fix [balanced install]
    if (strpos($folder,"//")===0){
       $addslash="//";
       $folder = substr($folder,2);
    }

    while(ereg("(\.\.)|(//)",$folder)){
		$folder = ereg_replace("(\.){2,}|(\|)*","",$folder);
		$folder = ereg_replace("(/){2,}","/",$folder);
	}

    $folder = $addslash.$folder;

    if($encode) {
      if(strcasecmp(mycharset,"us-ascii")) $folder = charsetconvert($folder,mycharset,"UTF7-IMAP");
      return str_replace("?","_",$folder);
    }
    else
      return $folder;
  }

  function convert_imaputf2charset($item,$charset=mycharset)
  {
    if(ereg("\&([a-zA-Z0-9\,\+])+\-",$item) && strcasecmp($charset,"us-ascii"))
    {
      $item = charsetconvert($item,"UTF7-IMAP",$charset);
      $item = str_replace("\x00","",$item);
      $item = str_replace("?","_",$item);
    }
    return $item;
  }


function getoptionfolder($id,$folders="",$folder="",$switch="",&$folderlist)
{
  if(!is_array($folders)) $folders = getfolders($id);

  for ($i = 0; $i < count($folders); $i++)
  {
          $folderlistitem = '<option value="'. $folders[$i][0].'"';

          if ($cpos = strpos($folders[$i][0],"^"))
             $compare = substr($folders[$i][0],0,$cpos);
          else
             $compare = $folders[$i][0];

          if ($folder && !(strcasecmp($folder,$compare)))
          {
                  $actualfolder_name = $folders[$i][1];
                  $folderlistitem .= ' selected';
          }

          $rslash = strrpos($folders[$i][1],"/");
          if($rslash>0)
          {
            $count=substr_count($folders[$i][1],"/");
            $nbsp="";
            for($ii=0;$ii<$count;$ii++) $nbsp.="-&nbsp;";
            $fname = substr($folders[$i][1],$rslash+1);
            if (strlen($fname)>21)
               $fname = substr($fname,0,18)."...";

            $folders[$i][1]= $nbsp.htmlspecialchars($fname);
          }
          elseif(strlen($folders[$i][1])>21)
            $folders[$i][1] = htmlspecialchars(substr($folders[$i][1],0,18))."...";

          $folderlistitem .= '>'. $folders[$i][1];
          if($switch) $folderlistitem .=' ' . showfolderinfo($folders[$i],$switch)."</option>\r\n"; else $folderlistitem .="</option>\r\n";

          $folderlists[] = $folderlistitem;
  }
  $folderlist = implode("", $folderlists);
  return $actualfolder_name;
}

////////////////////////////////////////////////////////////////////////////
//                              F O L D E R S                             //
////////////////////////////////////////////////////////////////////////////

  //03.12.2005
  function getfolderlist($path, &$folders, $dirlen="",$subdir=false)
  {
       global $otherconfig;

       if ($subdir){
          $fkey = count($folders)-1;
          if (!@file_exists($path.'index.dat'))
             indexfolder($path,$folders[$fkey]['messages'],$folders[$fkey]['unread'],$folders[$fkey]['size'],$xfolders);
          else
             parseindex($path,$folders[$fkey]['messages'],$folders[$fkey]['unread'],$folders[$fkey]['size'],$xfolders);
       }
       else {
          if(!$xfolders = glob("$path*",GLOB_ONLYDIR)) return false;
          $dirlen = strlen($path);
       }

       foreach ($xfolders as $dir) {
          if($subdir) $dir = $path.$dir;
          $folder = substr($dir,$dirlen);

          if ($subdir && !is_dir($dir)){
             changeindex($path,0,0,0,'',basename($dir));
             continue;
          }

          if ($folder[0]=='~') {
             if (!strcasecmp("$folder/",spamfolder.'/'))
                $folder = spamfolder;
             else
               continue;
          }

          $folders[] = array($folder,convert_imaputf2charset($folder),'');
          
          getfolderlist("$dir/", $folders, $dirlen, 1);
       }
  }

  //Fodler sort function
  function sortka(&$a,&$b){return strnatcasecmp($a[0],$b[0]);}

  //3.12.2005
  function getfolders($id)
  {
    global $otherconfig, $mailboxspam;
    getusersession($id, $user, $config);

    $path = usersdir . $user . "/";

    if (directmerak && $otherconfig["FULLMERAK"]) {
       $xpath = getmailboxpath($user, $imap, false);
       if ($imap || $otherconfig["MERAKMAILFOLDER"]) $path = $xpath;
    }
    $path = str_replace("\\","/",$path);

    getfolderlist($path, $folders2);

    if (is_array($folders2)) {
       usort($folders2,"sortka");

       foreach($folders2 as $key => $value) {
         if(strpos($value[0].'/',inboxfolder.'/')===0) {
           $finbox[]=$value;
           unset($folders2[$key]);
         }
         if(strpos($value[0].'/',draftsfolder.'/')===0) {
           $fdraft[]=$value;
           unset($folders2[$key]);
         }
         if(strpos($value[0].'/',sentfolder.'/')===0) {
           $fsent[]=$value;
           unset($folders2[$key]);
         }

         if(strpos($value[0].'/',trashfolder.'/')===0) {

           // trashfolder clean up
           if ($value[0]==trashfolder && $otherconfig["DELETETRASH"]) {
              if (($trfiles = glob($path.trashfolder."/*.{tmp,imap}",GLOB_BRACE))){
                 $ctime = time()-($otherconfig["DELETETRASH"] * 86400);
                 $trmssg  = $trumssg = $trsize = 0;
                 foreach ($trfiles as $trdir) {
                    if (filectime($trdir)<$ctime){
                       $trmssg--;
                       $trsize-=filesize($trdir);
                       $myflag = basename($trdir);
                       if (getmessageflag($id, trashfolder, $myflag) == unreadflag) $trumssg--;
                       @unlink($trdir);
                    }
                 }
                 if ($trmssg<0){
                    changeindex($path.trashfolder,$trmssg,$trumssg,$trsize);
                    $value['messages'] += $trmssg;
                    $value['unread'] += $trumssg;
                    $value['size'] += $trsize;
                 }
              }
           }

           $frash[]=$value;
           unset($folders2[$key]);
         }

         if(strpos($value[0].'/',spamfolder.'/')===0) {
           $fspam[]=$value;
           unset($folders2[$key]);
         }
       }
    }

    $finbox[0][0] = inboxfolder;
    $finbox[0][1] = uinboxfolder;
    $finbox[0][2] = " disabled";
    if (directmerak && $otherconfig["FULLMERAK"] && !$imap) {
          $popath = getfolderpath($user,inboxfolder);
          if (file_exists($popath.'index.dat'))
             parseindex($popath,$finbox[0]['messages'],$finbox[0]['unread'],$finbox[0]['size'],$x);
          else
             indexfolder($popath,$finbox[0]['messages'],$finbox[0]['unread'],$finbox[0]['size'],$x);
    }




    $fdraft[0][0] = draftsfolder;
    $fdraft[0][1] = udraftsfolder;
    $fdraft[0][2] = " disabled";

    $fsent[0][0] = sentfolder;
    $fsent[0][1] = usentfolder;
    $fsent[0][2] = " disabled";

    $frash[0][0] = trashfolder;
    $frash[0][1] = utrashfolder;
    $frash[0][2] = " disabled";

    $folders = array_merge($finbox,$fdraft,$fsent,$frash);

    if ($mailboxspam) {
       $fspam[0][0] = spamfolder;
       $fspam[0][1] = uspamfolder;
       $fspam[0][2] = " disabled";
       if (directmerak && $otherconfig["FULLMERAK"] && !$imap && !$otherconfig["MERAKMAILFOLDER"]) {
             $popath = getfolderpath($user,spamfolder);
             if (file_exists($popath.'index.dat'))
                parseindex($popath,$fspam[0]['messages'],$fspam[0]['unread'],$fspam[0]['size'],$x);
             else
                indexfolder($popath,$fspam[0]['messages'],$fspam[0]['unread'],$fspam[0]['size'],$x);
       }
       $folders = array_merge($folders,$fspam);
    }

    if(is_array($folders2)) $folders=array_merge($folders,$folders2);

    return $folders;
  }
?>
